import { h, Component } from 'preact'
import BooleanInput from '@hashicorp/hashi-boolean-input'
import withValidation from '@hashicorp/hashi-with-validation'

const ValidatedBooleanInput = withValidation(BooleanInput)

/**
 * Hashicorp uses this privacy poliy checkbox across a range of forms including
 * sales, webinar and trial forms.
 * @prop {Function} [onValidityChange] - function called with true/false when all
 * checkbox is valid (checked).
 * @prop {Boolean} forceValidate - if set to true, will force all fields to run
 * their validate functions
 * @prop {Boolean} on_dark - adjust css for dark backgrounds
 */
export default class PrivacyCheckbox extends Component {
  constructor(props) {
    super(props)
    this.state = {
      privacyValidity: null
    }
  }
  componentDidUpdate(prevProps, prevState) {
    if (this.state.privacyValidity !== prevState.privacyValidity) {
      this.props.onValidityChange &&
        this.props.onValidityChange(this.state.privacyValidity)
    }
  }
  render() {
    return (
      <ValidatedBooleanInput
        label="I agree to HashiCorp’s <a href='/privacy' target='_blank'>Privacy Policy</a>."
        name="privacyPolicy"
        on_dark={this.props.on_dark}
        onValidityChange={s =>
          this.setState({ privacyValidity: s !== 'error' })
        }
        forceValidate={this.props.forceValidate}
        validate={value => {
          if (value) {
            return { status: 'success', message: null }
          } else {
            return {
              status: 'error',
              message: 'You must agree to the privacy policy to continue.'
            }
          }
        }}
      />
    )
  }
}
